unit uSonyFont;

interface

type
  TSonyFontFamily = (sffSerif, sffSansSerif, sffMonospace, sffMonospaceAlt);

procedure PrepareSonyFont(const InputFileName, OutputFileName: string; Family: TSonyFontFamily); overload;
procedure PrepareSonyFont(const InputFileName: string; Family: TSonyFontFamily); overload;
procedure PrepareSonyFont(const InputFileName: string; Family: TSonyFontFamily; const Dir: string); overload;

implementation

uses
  SysUtils, uTrueType, uTrueTypeConst;

const
  SonyFontFileNames: array[TSonyFontFamily] of WideString
    = ('tt0011m_.ttf', 'tt0003m_.ttf', 'tt0419m_.ttf', 'tt0419m_.ttf');
  SonyFontFamilies: array[TSonyFontFamily] of WideString
    = ('Dutch801 Rm BT', 'Swis721 BT', 'Courier10 BT', 'Courier10 Win95BT');
  SonyFontSubFamilies: array[TSonyFontFamily] of WideString
    = ('Roman', 'Roman', 'Roman', 'Roman');
  SonyFontFullFontNames: array[TSonyFontFamily] of WideString
    = ('Dutch801 Rm BT Roman', 'Swis721 BT Roman', 'Courier10 BT Roman', 'Courier10 Pitch Win95BT');


procedure PrepareSonyFont(const InputFileName, OutputFileName: string; Family: TSonyFontFamily);
var FontFile: TTrueTypeFont;

  procedure SetFontNamingForIDs(FontNameID: integer; const FontNamingValue: WideString);
    begin
      FontFile.SetFontNaming(FontNameID, FontNamingValue, TT_FONTPLATFORM_APPLEUNICODE);
      FontFile.SetFontNaming(FontNameID, FontNamingValue, TT_FONTPLATFORM_MACINTOSH);
      FontFile.SetFontNaming(FontNameID, FontNamingValue, TT_FONTPLATFORM_MICROSOFT);
      FontFile.SetFontNaming(FontNameID, FontNamingValue);
    end;

begin
  FontFile := TTrueTypeFont.Create(nil);
  try
    FontFile.LoadFromFile(InputFileName);
    SetFontNamingForIDs(TT_FONTNAMEID_FONTFAMILY,    SonyFontFamilies[Family]);
    SetFontNamingForIDs(TT_FONTNAMEID_FONTSUBFAMILY, SonyFontSubFamilies[Family]);
    SetFontNamingForIDs(TT_FONTNAMEID_FULLNAME,      SonyFontFullFontNames[Family]);
    FontFile.ApplyChanges;
    FontFile.SaveToFile(OutputFileName);
  finally
    FontFile.Free;
    end;
end;

procedure PrepareSonyFont(const InputFileName: string; Family: TSonyFontFamily; const Dir: string); 
begin
  if Dir = '' then
    PrepareSonyFont(InputFileName, SonyFontFilenames[Family], Family)
  else
    PrepareSonyFont(InputFileName, IncludeTrailingBackslash(Dir) + SonyFontFilenames[Family], Family)
end;


procedure PrepareSonyFont(const InputFileName: string; Family: TSonyFontFamily);
begin
  PrepareSonyFont(InputFileName, Family, ExtractFilePath(InputFileName));
end;

end.
